<?php

namespace Drupal\easychart\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\easychart\EasychartHelper;

/**
 * Provides a default Easychart formatter.
 *
 * @FieldFormatter(
 *   id = "easychart_default",
 *   module = "easychart",
 *   label = @Translation("Default"),
 *   field_types = {
 *     "easychart"
 *   },
 *   quickedit = {
 *     "editor" = "disabled"
 *   }
 * )
 */
class Easychart extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    // Unique distinction by $uuid & $delta.
    $uuid = $items->getEntity()->uuid();
    $field_name = $this->fieldDefinition->getFieldStorageDefinition()->getName();
    $element = [];

    foreach ($items as $delta => $item) {
      if ($output = EasychartHelper::easychartPrintChart($item->getValue(), $uuid, $delta, $field_name)) {
        $element[$delta] = ['#markup' => $output['markup']];
        $element['#attached']['drupalSettings']['easychart'][$output['identifier']] = [
          'config' => $output['config'],
          'csv' => $output['csv'],
          'presets' => $output['presets'],
        ];
      }
    }

    if (!empty($element)) {
      EasychartHelper::addRenderLibraries($element);
    }

    return $element;
  }

}
